@@ -1,6 +1,6 @@
 # Model menu dialogs
 
-# last modified 2016-08-10 by J. Fox
+# last modified 2018-03-20 by J. Fox
 
 selectActiveModel <- function(){
 	models <- listAllModels()
@@ -113,131 +113,133 @@ plotModel <- function(){
 }
 
 CRPlots <- function(){
-    .activeModel <- ActiveModel()
-    if (is.null(.activeModel) || !checkMethod("crPlot", .activeModel)) return()
-    
-    defaults <- list(initial.span=50)
-    dialog.values <- getDialog("CRPlots", defaults)
-    initializeDialog(title = gettextRcmdr("Component+Residual Plots"))
-    sliderValue <- tclVar(dialog.values$initial.span)
-    sliderFrame <- tkframe(top)
-    slider <- tkscale(sliderFrame, from = 5, to = 100, showvalue = TRUE, 
-                      variable = sliderValue, resolution = 5, orient = "horizontal")
-    onOK <- function(){
-        span <- as.numeric(tclvalue(sliderValue))
-        closeDialog()
-        putDialog ("CRPlots", list(initial.span=span))
-        doItAndPrint(paste("crPlots(", .activeModel, ", span=", span/100, ")", sep=""))
-        activateMenus()
-        tkfocus(CommanderWindow())
-    }
-    OKCancelHelp(helpSubject = "crPlots", reset = "CRPlots", apply = "CRPlots")
-    tkgrid(labelRcmdr(sliderFrame, text=gettextRcmdr("Span for smooth")), slider, sticky="sw")
-    tkgrid(sliderFrame, sticky="w")
-    tkgrid(buttonsFrame, sticky="w")
-    dialogSuffix()
+  .activeModel <- ActiveModel()
+  if (is.null(.activeModel) || !checkMethod("crPlot", .activeModel)) return()
+  
+  defaults <- list(initial.span=50)
+  dialog.values <- getDialog("CRPlots", defaults)
+  initializeDialog(title = gettextRcmdr("Component+Residual Plots"))
+  sliderValue <- tclVar(dialog.values$initial.span)
+  sliderFrame <- tkframe(top)
+  slider <- tkscale(sliderFrame, from = 5, to = 100, showvalue = TRUE, 
+                    variable = sliderValue, resolution = 5, orient = "horizontal")
+  onOK <- function(){
+    span <- as.numeric(tclvalue(sliderValue))
+    closeDialog()
+    putDialog ("CRPlots", list(initial.span=span))
+    doItAndPrint(paste("crPlots(", .activeModel, ", smooth=list(span=", span/100, "))", sep=""))
+    activateMenus()
+    tkfocus(CommanderWindow())
+  }
+  OKCancelHelp(helpSubject = "crPlots", reset = "CRPlots", apply = "CRPlots")
+  tkgrid(labelRcmdr(sliderFrame, text=gettextRcmdr("Span for smooth")), slider, sticky="sw")
+  tkgrid(sliderFrame, sticky="w")
+  tkgrid(buttonsFrame, sticky="w")
+  dialogSuffix()
 }
 
 AVPlots <- function () {
-    .activeModel <- ActiveModel()
-    if (is.null(.activeModel) || !checkMethod("avPlot", .activeModel)) 
-        return()
-    defaults <- list (initial.identify = "auto", initial.id.n="2")
-    dialog.values <- getDialog ("AVPlots", defaults)
-    initializeDialog(title = gettextRcmdr("Added-Variable Plots"))
-    identifyPointsFrame <- tkframe(top)
-    radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse", 
-                                                                     "not"), labels = gettextRcmdr(c("Automatically", 
-                                                                                                     "Interactively with mouse", "Do not identify")), title = gettextRcmdr("Identify Points"), 
-                 initialValue = dialog.values$initial.identify)    
-    id.n.Var <- tclVar(dialog.values$initial.id.n) 
-    npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
-    onOK <- function() {
-        id.n <- tclvalue(id.n.Var)
-        identify <- tclvalue(identifyVariable)
-        method <- if (identify == "mouse") "identify" else "mahal"
-        id.n.use <- if (identify == "not") 0 else id.n   
-        closeDialog()
-        if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
-            errorCondition(recall = AVPlots, message = gettextRcmdr("number of points to identify must be an integer"))
-            return()
-        }
-        putDialog ("AVPlots", list (initial.identify = identify, initial.id.n=id.n))
-        if (identify == "mouse") {
-            RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
-                                                                         gettextRcmdr(if (MacOSXP()) 
-                                                                             "esc key to exit."
-                                                                                      else "right button to exit."), sep = ""), icon = "info", 
-                              type = "ok")
-        }
-        command <- paste("avPlots(", .activeModel, ', id.method="', method, '", id.n=', id.n.use,  ")", sep = "")
-        if (identify == "mouse") command <- suppressMarkdown(command)
-        doItAndPrint(command)
-        activateMenus()
-        tkfocus(CommanderWindow())
+  .activeModel <- ActiveModel()
+  if (is.null(.activeModel) || !checkMethod("avPlot", .activeModel)) 
+    return()
+  defaults <- list (initial.identify = "auto", initial.id.n="2")
+  dialog.values <- getDialog ("AVPlots", defaults)
+  initializeDialog(title = gettextRcmdr("Added-Variable Plots"))
+  identifyPointsFrame <- tkframe(top)
+  radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse", 
+                                                                   "not"), labels = gettextRcmdr(c("Automatically", 
+                                                                                                   "Interactively with mouse", "Do not identify")), title = gettextRcmdr("Identify Points"), 
+               initialValue = dialog.values$initial.identify)    
+  id.n.Var <- tclVar(dialog.values$initial.id.n) 
+  npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
+  onOK <- function() {
+    id.n <- tclvalue(id.n.Var)
+    identify <- tclvalue(identifyVariable)
+    method <- if (identify == "mouse") "identify" else "mahal"
+    id.n.use <- if (identify == "not") 0 else id.n   
+    closeDialog()
+    if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
+      errorCondition(recall = AVPlots, message = gettextRcmdr("number of points to identify must be an integer"))
+      return()
     }
-    OKCancelHelp(helpSubject = "avPlots", reset = "AVPlots", apply = "AVPlots")
-    tkgrid(identifyFrame, sticky="w")
-    tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
-    tkgrid(identifyPointsFrame, sticky="w")
-    tkgrid(buttonsFrame, sticky = "w")
-    dialogSuffix()
+    putDialog ("AVPlots", list (initial.identify = identify, initial.id.n=id.n))
+    if (identify == "mouse") {
+      RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
+                                                                   gettextRcmdr(if (MacOSXP()) 
+                                                                     "esc key to exit."
+                                                                     else "right button to exit."), sep = ""), icon = "info", 
+                        type = "ok")
+    }
+    command <- paste("avPlots(", .activeModel, ', id=list(method="', method, '", n=', id.n.use,  "))", sep = "")
+    if (identify == "mouse") command <- suppressMarkdown(command)
+    doItAndPrint(command)
+    activateMenus()
+    tkfocus(CommanderWindow())
+  }
+  OKCancelHelp(helpSubject = "avPlots", reset = "AVPlots", apply = "AVPlots")
+  tkgrid(identifyFrame, sticky="w")
+  tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
+  tkgrid(identifyPointsFrame, sticky="w")
+  tkgrid(buttonsFrame, sticky = "w")
+  dialogSuffix()
 }
 
 InfluencePlot <- function () {
-    .activeModel <- ActiveModel()
-    if (is.null(.activeModel) || !checkMethod("influencePlot", .activeModel)) 
-        return()
-    defaults <- list (initial.identify = "auto", initial.id.n="2")
-    dialog.values <- getDialog ("InfluencePlot", defaults)
-    initializeDialog(title = gettextRcmdr("Influence Plot"))
-    identifyPointsFrame <- tkframe(top)
-    radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse"), labels = gettextRcmdr(c("Automatically", 
-                                                                                                               "Interactively with mouse")), title = gettextRcmdr("Identify Points"), 
-                 initialValue = dialog.values$initial.identify)    
-    id.n.Var <- tclVar(dialog.values$initial.id.n) 
-    npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
-    onOK <- function() {
-        id.n <- tclvalue(id.n.Var)
-        identify <- tclvalue(identifyVariable)
-        method <- if (identify == "mouse") "identify" else "noteworthy"
-        closeDialog()
-        if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
-            errorCondition(recall = InfluencePlot, message = gettextRcmdr("number of points to identify must be an integer"))
-            return()
-        }
-        putDialog ("InfluencePlot", list (initial.identify = identify, initial.id.n=id.n))
-        if (identify == "mouse") {
-            RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
-                                                                         gettextRcmdr(if (MacOSXP()) 
-                                                                             "esc key to exit."
-                                                                                      else "right button to exit."), sep = ""), icon = "info", 
-                              type = "ok")
-        }
-        command <- paste("influencePlot(", .activeModel, ', id.method="', method, '", id.n=', id.n,  ")", sep = "")
-        if (identify == "mouse") command <- suppressMarkdown(command)
-        doItAndPrint(command)
-        activateMenus()
-        tkfocus(CommanderWindow())
+  .activeModel <- ActiveModel()
+  if (is.null(.activeModel) || !checkMethod("influencePlot", .activeModel)) 
+    return()
+  defaults <- list (initial.identify = "auto", initial.id.n="2")
+  dialog.values <- getDialog ("InfluencePlot", defaults)
+  initializeDialog(title = gettextRcmdr("Influence Plot"))
+  identifyPointsFrame <- tkframe(top)
+  radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse"), labels = gettextRcmdr(c("Automatically", 
+                                                                                                             "Interactively with mouse")), title = gettextRcmdr("Identify Points"), 
+               initialValue = dialog.values$initial.identify)    
+  id.n.Var <- tclVar(dialog.values$initial.id.n) 
+  npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
+  onOK <- function() {
+    id.n <- tclvalue(id.n.Var)
+    identify <- tclvalue(identifyVariable)
+    method <- if (identify == "mouse") "identify" else "noteworthy"
+    closeDialog()
+    if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
+      errorCondition(recall = InfluencePlot, message = gettextRcmdr("number of points to identify must be an integer"))
+      return()
     }
-    OKCancelHelp(helpSubject = "influencePlot", reset = "InfluencePlot", apply = "InfluencePlot")
-    tkgrid(identifyFrame, sticky="w")
-    tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
-    tkgrid(identifyPointsFrame, sticky="w")
-    tkgrid(buttonsFrame, sticky = "w")
-    dialogSuffix()
+    putDialog ("InfluencePlot", list (initial.identify = identify, initial.id.n=id.n))
+    if (identify == "mouse") {
+      RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
+                                                                   gettextRcmdr(if (MacOSXP()) 
+                                                                     "esc key to exit."
+                                                                     else "right button to exit."), sep = ""), icon = "info", 
+                        type = "ok")
+    }
+    command <- paste("influencePlot(", .activeModel, ', id=list(method="', method, '", n=', id.n,  "))", sep = "")
+    if (identify == "mouse") command <- suppressMarkdown(command)
+    doItAndPrint(command)
+    activateMenus()
+    tkfocus(CommanderWindow())
+  }
+  OKCancelHelp(helpSubject = "influencePlot", reset = "InfluencePlot", apply = "InfluencePlot")
+  tkgrid(identifyFrame, sticky="w")
+  tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
+  tkgrid(identifyPointsFrame, sticky="w")
+  tkgrid(buttonsFrame, sticky = "w")
+  dialogSuffix()
 }
 
 anovaTable <- function () {
     .activeModel <- ActiveModel()
     if (is.null(.activeModel)) 
         return()
-    defaults <- list (initial.type = "II", initial.sandwich="0", initial.sandwich.type="HC3")
+    aov <- modelCapability("aov")
+    Aov <- modelCapability("Aov")
+    defaults <- list (initial.type = if (Aov) "II" else "I", initial.sandwich="0", initial.sandwich.type="HC3")
     dialog.values <- getDialog ("anovaTable", defaults)
     initializeDialog(title = gettextRcmdr("ANOVA Table"))
-    radioButtons(name = "type", buttons = c("I", "II", "III"), 
-        values = c("I", "II", "III"), labels = gettextRcmdr(c("Sequential (\"Type I\")", 
-            "Partial obeying marginality (\"Type II\")", "Partial ignoring marginality (\"Type III\")")), 
+    radioButtons(name = "type", buttons = c(if (aov) "I", if(Aov) c("II", "III")), 
+        values = c(if (aov) "I", if (Aov) c("II", "III")), labels = gettextRcmdr(c(if (aov) "Sequential (\"Type I\")", 
+            if (Aov) c("Partial obeying marginality (\"Type II\")", "Partial ignoring marginality (\"Type III\")"))), 
         title = gettextRcmdr("Type of Tests"), initialValue = dialog.values$initial.type)
     sandwichVar <- tclVar(dialog.values$initial.sandwich)
     sandwichFrame <- tkframe(top)
@@ -323,6 +325,7 @@ VIF <- function(){
 	.activeModel <- ActiveModel()
 	if (is.null(.activeModel) || !checkMethod("vif", .activeModel, default=TRUE)) return()
 	doItAndPrint(paste("vif(", .activeModel, ")", sep=""))
+	doItAndPrint(paste("round(cov2cor(vcov(", .activeModel, ")), 3) # Correlations of parameter estimates", sep=""))
 }
 
 addObservationStatistics <- function () {
@@ -351,32 +354,38 @@ addObservationStatistics <- function () {
   initializeDialog(title = gettextRcmdr("Add Observation Statistics to Data"))
   .variables <- Variables()
   obsNumberExists <- is.element("obsNumber", .variables)
-  activate <- c(checkMethod("fitted", .activeModel, default = TRUE, 
-                            reportError = FALSE), checkMethod("residuals", .activeModel, 
-                                                              default = TRUE, reportError = FALSE), checkMethod("rstudent", 
-                                                                                                                .activeModel, reportError = FALSE), checkMethod("hatvalues", 
-                                                                                                                                                                .activeModel, reportError = FALSE), checkMethod("cooks.distance", 
-                                                                                                                                                                                                                .activeModel, reportError = FALSE))
+  # activate <- c(checkMethod("fitted", .activeModel, default = TRUE, 
+  #                           reportError = FALSE), checkMethod("residuals", .activeModel, 
+  #                                                             default = TRUE, reportError = FALSE), checkMethod("rstudent", 
+  #                                                                                                               .activeModel, reportError = FALSE), checkMethod("hatvalues", 
+  #                                                                                                                                                               .activeModel, reportError = FALSE), checkMethod("cooks.distance", 
+  #                                                                                                                                                                                                              .activeModel, reportError = FALSE))
+  activate <- c(modelCapability("fit"), modelCapability("res"), modelCapability("rst"), modelCapability("hat"), modelCapability("cook"))
   checkBoxes(frame = "selectFrame", boxes = c(c("fitted", "residuals", 
                                                 "rstudent", "hatvalues", "cookd")[activate], "obsNumbers"), 
              labels = c(gettextRcmdr(c("Fitted values", "Residuals", 
                                        "Studentized residuals", "Hat-values", "Cook's distances"))[activate], 
-                        gettextRcmdr("Observation indices")), initialValues = c(dialog.values$initial.fitted, 
+                        gettextRcmdr("Observation indices")), initialValues = c(c(dialog.values$initial.fitted, 
                                                                                 dialog.values$initial.residuals, dialog.values$initial.rstudent, 
-                                                                                dialog.values$initial.hatvalues, dialog.values$initial.cookd, dialog.values$initial.obsNumbers))
+                                                                                dialog.values$initial.hatvalues, dialog.values$initial.cookd)[activate], dialog.values$initial.obsNumbers))
   command <- paste(.activeDataSet, "<- within(", .activeDataSet, ", {", sep="")
   onOK <- function() {
     closeDialog()
     if (activate[1] && tclvalue(fittedVariable) == 1) 
       command <- paste(command, "\n  ", addVariable("fitted"), sep="")
+    else fittedVariable <- tclVar(0)
     if (activate[2] && tclvalue(residualsVariable) == 1) 
       command <- paste(command, "\n  ", addVariable("residuals"), sep="")
+    else residualsVariable <- tclVar(0)
     if (activate[3] && tclvalue(rstudentVariable) == 1) 
       command <- paste(command, "\n  ", addVariable("rstudent"), sep="")
+    else rstudentVariable <- tclVar(0)
     if (activate[4] && tclvalue(hatvaluesVariable) == 1) 
       command <- paste(command, "\n  ", addVariable("hatvalues"), sep="")
+    else hatvaluesVariable <- tclVar(0)
     if (activate[5] && tclvalue(cookdVariable) == 1) 
       command <- paste(command, "\n  ", addVariable("cooks.distance"), sep="")
+    else cookdVariable <- tclVar(0)
     obsNumbers <- tclvalue(obsNumbersVariable)
     putDialog ("addObservationStatistics", list (initial.fitted = tclvalue (fittedVariable),
                                                  initial.residuals = tclvalue (residualsVariable), initial.rstudent = tclvalue(rstudentVariable), 
@@ -402,58 +411,58 @@ addObservationStatistics <- function () {
 }
 
 residualQQPlot <- function () {
-    .activeModel <- ActiveModel()
-    if (is.null(.activeModel) || !checkMethod("qqPlot", .activeModel)) 
-        return()
-    defaults <- list (initial.simulate = 1, initial.identify = "auto", initial.id.n="2")
-    dialog.values <- getDialog ("residualQQPlot", defaults)
-    initializeDialog(title = gettextRcmdr("Residual Quantile-Comparison Plot"))
-    selectFrame <- tkframe(top)
-    simulateVar <- tclVar(dialog.values$initial.simulate)
-    simulateCheckBox <- ttkcheckbutton(selectFrame, variable = simulateVar)
-    identifyPointsFrame <- tkframe(top)
-    radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse", 
-                                                                     "not"), labels = gettextRcmdr(c("Automatically", 
-                                                                                                     "Interactively with mouse", "Do not identify")), title = gettextRcmdr("Identify Points"), 
-                 initialValue = dialog.values$initial.identify)    
-    id.n.Var <- tclVar(dialog.values$initial.id.n) 
-    npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
-    onOK <- function() {
-        simulate <- tclvalue (simulateVar)  
-        id.n <- tclvalue(id.n.Var)
-        identify <- tclvalue(identifyVariable)
-        method <- if (identify == "mouse") "identify" else "y"
-        id.n.use <- if (identify == "not") 0 else id.n   
-        closeDialog()
-        if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
-            errorCondition(recall = residualQQPlot, message = gettextRcmdr("number of points to identify must be an integer"))
-            return()
-        }
-        putDialog ("residualQQPlot", list (initial.simulate = simulate, initial.identify = identify, initial.id.n=id.n))
-        simulate <- tclvalue(simulateVar) == 1
-        if (identify == "mouse") {
-            RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
-                                                                         gettextRcmdr(if (MacOSXP()) 
-                                                                             "esc key to exit."
-                                                                                      else "right button to exit."), sep = ""), icon = "info", 
-                              type = "ok")
-        }
-        command <- paste("qqPlot(", .activeModel, ", simulate=", 
-                         simulate, ', id.method="', method, '", id.n=', id.n.use,  ")", sep = "")
-        if (identify == "mouse") command <- suppressMarkdown(command)
-        doItAndPrint(command)
-        activateMenus()
-        tkfocus(CommanderWindow())
+  .activeModel <- ActiveModel()
+  if (is.null(.activeModel) || !checkMethod("qqPlot", .activeModel)) 
+    return()
+  defaults <- list (initial.simulate = 1, initial.identify = "auto", initial.id.n="2")
+  dialog.values <- getDialog ("residualQQPlot", defaults)
+  initializeDialog(title = gettextRcmdr("Residual Quantile-Comparison Plot"))
+  selectFrame <- tkframe(top)
+  simulateVar <- tclVar(dialog.values$initial.simulate)
+  simulateCheckBox <- ttkcheckbutton(selectFrame, variable = simulateVar)
+  identifyPointsFrame <- tkframe(top)
+  radioButtons(identifyPointsFrame, name = "identify", buttons = c("auto", "mouse", 
+                                                                   "not"), labels = gettextRcmdr(c("Automatically", 
+                                                                                                   "Interactively with mouse", "Do not identify")), title = gettextRcmdr("Identify Points"), 
+               initialValue = dialog.values$initial.identify)    
+  id.n.Var <- tclVar(dialog.values$initial.id.n) 
+  npointsSpinner <- tkspinbox(identifyPointsFrame, from=1, to=10, width=2, textvariable=id.n.Var)      
+  onOK <- function() {
+    simulate <- tclvalue (simulateVar)  
+    id.n <- tclvalue(id.n.Var)
+    identify <- tclvalue(identifyVariable)
+    method <- if (identify == "mouse") "identify" else "y"
+    id.n.use <- if (identify == "not") 0 else id.n   
+    closeDialog()
+    if (is.na(suppressWarnings(as.numeric(id.n))) || round(as.numeric(id.n)) != as.numeric(id.n)){
+      errorCondition(recall = residualQQPlot, message = gettextRcmdr("number of points to identify must be an integer"))
+      return()
     }
-    OKCancelHelp(helpSubject = "qqPlot.lm", reset = "residualQQPlot", apply = "residualQQPlot")
-    tkgrid(labelRcmdr(selectFrame, text = gettextRcmdr("Simulated confidence envelope")), 
-           simulateCheckBox, sticky = "w")
-    tkgrid(selectFrame, sticky = "w")
-    tkgrid(identifyFrame, sticky="w")
-    tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
-    tkgrid(identifyPointsFrame, sticky="w")
-    tkgrid(buttonsFrame, sticky = "w")
-    dialogSuffix()
+    putDialog ("residualQQPlot", list (initial.simulate = simulate, initial.identify = identify, initial.id.n=id.n))
+    simulate <- tclvalue(simulateVar) == 1
+    if (identify == "mouse") {
+      RcmdrTkmessageBox(title = "Identify Points", message = paste(gettextRcmdr("Use left mouse button to identify points,\n"), 
+                                                                   gettextRcmdr(if (MacOSXP()) 
+                                                                     "esc key to exit."
+                                                                     else "right button to exit."), sep = ""), icon = "info", 
+                        type = "ok")
+    }
+    command <- paste("qqPlot(", .activeModel, ", simulate=", 
+                     simulate, ', id=list(method="', method, '", n=', id.n.use,  "))", sep = "")
+    if (identify == "mouse") command <- suppressMarkdown(command)
+    doItAndPrint(command)
+    activateMenus()
+    tkfocus(CommanderWindow())
+  }
+  OKCancelHelp(helpSubject = "qqPlot.lm", reset = "residualQQPlot", apply = "residualQQPlot")
+  tkgrid(labelRcmdr(selectFrame, text = gettextRcmdr("Simulated confidence envelope")), 
+         simulateCheckBox, sticky = "w")
+  tkgrid(selectFrame, sticky = "w")
+  tkgrid(identifyFrame, sticky="w")
+  tkgrid(labelRcmdr(identifyPointsFrame, text=gettextRcmdr("Number of points to identify  ")), npointsSpinner, sticky="w")
+  tkgrid(identifyPointsFrame, sticky="w")
+  tkgrid(buttonsFrame, sticky = "w")
+  dialogSuffix()
 }
 
 testLinearHypothesis <- function(){
@@ -973,7 +982,6 @@ subsetRegression <- function () {
 }
 
 effectPlots <- function () {
-  Library("effects")
   defaults <- list(initial.all.or.pick = "TRUE", initial.predictors = NULL, 
                    initial.partial.res = 0, initial.span = 50, initial.style = "stacked")
   dialog.values <- getDialog("effectPlots", defaults)
@@ -1009,9 +1017,9 @@ effectPlots <- function () {
     closeDialog() 
     if (allEffects){
       command <- if (class(get(activeModel(), envir=.GlobalEnv))[1] %in% c("multinom", "polr"))
-        paste("plot(allEffects(", activeModel(), '), style="', style, '")', sep="")
+        paste("plot(allEffects(", activeModel(), '), axes=list(y=list(style="', style, '")))', sep="")
       else paste("plot(allEffects(", activeModel(), 
-                 if (partial.residuals) paste(", partial.residuals=TRUE), span=", span/100, ")", sep="")
+                 if (partial.residuals) paste(", residuals=TRUE), partial.residuals=list(span=", span/100, "))", sep="")
                  else "))", sep="")
       doItAndPrint(command)
       predictors <- NULL
@@ -1029,9 +1037,9 @@ effectPlots <- function () {
       }
       command <- if (class(get(activeModel(), envir=.GlobalEnv))[1] %in% c("multinom", "polr"))
         paste("plot(Effect(c(", paste(paste('"', predictors, '"', sep=""), collapse=", "), "), ", 
-              activeModel(), '), style="', style, '")', sep="")      
+              activeModel(), '), axes=list(y=list(style="', style, '")))', sep="")      
       else paste("plot(Effect(c(", paste(paste('"', predictors, '"', sep=""), collapse=", "), "), ", activeModel(),
-                 if (partial.residuals) paste(", partial.residuals=TRUE), span=", span/100, ")", sep="")
+                 if (partial.residuals) paste(", residuals=TRUE), partial.residuals=list(span=", span/100, "))", sep="")
                  else "))", sep = "")
       doItAndPrint(command)
     }
@@ -1068,7 +1076,7 @@ Bootstrap <- function () {
     .activeModel <- ActiveModel()
     if (is.null(.activeModel)) 
         return()
-    defaults <- list (initial.level = "0.95", initial.samples="999", initial.type="bca", initial.method="case")
+    defaults <- list (initial.level = "0.95", initial.samples="999", initial.type="bca", initial.method="case", initial.plot="1")
     dialog.values <- getDialog ("Bootstrap", defaults)
     initializeDialog(title = gettextRcmdr("Bootstrap"))
     tkgrid(labelRcmdr(top, text = gettextRcmdr("Bootstrap Confidence Intervals for Coefficients"), 
@@ -1098,13 +1106,25 @@ Bootstrap <- function () {
         }
         else defaults$initial.method
         type <- tclvalue(typeVariable)
-        putDialog ("Bootstrap", list (initial.level = level, initial.samples = samples, initial.type=type, initial.method = method))
+        plot.samples <- tclvalue(plotVar)
+        putDialog ("Bootstrap", list (initial.level = level, initial.samples = samples, initial.type=type, initial.method = method, 
+                                      initial.plot=plot.samples))
         command <- if (lm) 
-            paste0('confint(Boot(', .activeModel, ', R=', samples, ', method="', method, '"), level=', level, 
-                   ', type="', type, '")' )
-        else paste0("confint(Boot(", .activeModel, ', R=', samples, '), level=', level, 
-                    ', type="', type, '")' )
+            paste0('Boot(', .activeModel, ', R=', samples, ', method="', method, '")')
+        else paste0("Boot(", .activeModel, ', R=', samples, ')')
+        
+        if (plot.samples == "0"){
+            command <- paste0("confint(", command, ',  level=', level, ', type="', type, '")')
+            doItAndPrint(command)
+            return()
+        }
+        
+        command <- paste0(".bs.samples <- ", command, "\n",
+                          "plotBoot(.bs.samples)")
         doItAndPrint(command)
+        doItAndPrint(paste0('confint(.bs.samples, level=', level, ', type="', type, '")'))
+        logger("remove(.bs.samples)")
+        justDoIt("remove(.bs.samples, envir=.GlobalEnv)")
         tkfocus(CommanderWindow())
     }
     OKCancelHelp(helpSubject = "Boot", reset = "Bootstrap", apply = "Bootstrap")
@@ -1131,6 +1151,11 @@ Bootstrap <- function () {
                      labels = gettextRcmdr(c("Case resampling", "Residual resampling")), title = gettextRcmdr("Resampling Method"))
         tkgrid(methodFrame, sticky="w")
     }
+    plotVar <- tclVar(dialog.values$initial.plot)
+    plotFrame <- tkframe(top)
+    plotCheckBox <- ttkcheckbutton(plotFrame, variable = plotVar)
+    tkgrid(tklabel(plotFrame, text=gettextRcmdr("Plot bootstrap samples"), fg=getRcmdr("title.color")), plotCheckBox, sticky="w")
+    tkgrid(plotFrame, sticky="w")
     tkgrid(buttonsFrame, sticky = "w")
     dialogSuffix()
 }
